@@ -1,5 +1,8 @@
-import os,sys,logging
+import sys
+import logging
+import os
 from abc import ABC,abstractmethod
+import yaml
 logging_str = "[%(asctime)s: %(levelname)s: %(module)s]: %(message)s"
 #log_dir = "logs"
 #log_filepath = os.path.join(log_dir, "running_logs.log")
@@ -10,6 +13,11 @@ logging_str = "[%(asctime)s: %(levelname)s: %(module)s]: %(message)s"
 #os.makedirs(log_dir, exist_ok=True)
 # logging.FileHandler(log_filepath),
 
+def read_yaml(path:str):
+    with open(path) as f:
+        d=yaml.safe_load(f)
+    return d
+
 logging.basicConfig(
     level=logging.INFO, 
     format=logging_str,
